ClockSynchronization

Struct ClockSynchronization 

pub struct ClockSynchronization<A: Time, B: Time> { /* private fields */ }
A pair of instants from two clocks that correspond to roughly the same point in time.

Implementations

Source

impl<A: Time, B: Time> ClockSynchronization<A, B>

pub fn new(epoch_a: A::Instant, epoch_b: B::Instant) -> Self

Creates a synchronization from a known pair of corresponding instants.

pub fn new_aba_calibrated<CA, CB>(a: &CalibratedClock<CA>, b: &CB) -> Self
where CA: Clock<Time = A>, CB: Clock<Time = B>,

Creates a synchronization by sampling both clocks in an A-B-A pattern.

Multiple measurements are performed and the one with least error is selected.

pub fn to_a<CA, CB>(&self, t: B::Instant, a: &CA, b: &CB) -> A::Instant

Converts an instant from clock B’s domain to clock A’s domain.

Works for instants both before and after the synchronization epoch.

pub fn to_b<CA, CB>(&self, t: A::Instant, a: &CA, b: &CB) -> B::Instant

Converts an instant from clock A’s domain to clock B’s domain.

Works for instants both before and after the synchronization epoch.

pub fn to_a_after_epoch<CA, CB>( &self, t: B::Instant, a: &CA, b: &CB, ) -> A::Instant

Converts an instant from clock B’s domain to clock A’s domain, assuming t is at or after the synchronization epoch.

Possibly faster than to_a. Behavior when t is before the epoch is unspecified: The function may panic or return a meaningless value. Use to_a if unsure.

pub fn to_b_after_epoch<CA, CB>( &self, t: A::Instant, a: &CA, b: &CB, ) -> B::Instant

Converts an instant from clock A’s domain to clock B’s domain, assuming t is at or after the synchronization epoch.

Possibly faster than to_b. Behavior when t is before the epoch is unspecified: The function may panic or return a meaningless value. Use to_b if unsure.

pub fn epoch_a(&self) -> A::Instant

Returns the synchronization epoch in clock A’s domain.

pub fn epoch_b(&self) -> B::Instant

Returns the synchronization epoch in clock B’s domain.