pub struct U64Calibration { /* private fields */ }Expand description
Integer multiply-shift calibration for WrappingU64Duration.
Converts between raw ticks and nanoseconds using precomputed multiply-shift factors.
Implementations
Sourceimpl U64Calibration
impl U64Calibration
Sourcepub fn new(duration: WrappingU64Duration, duration_ns: u64) -> Self
pub fn new(duration: WrappingU64Duration, duration_ns: u64) -> Self
Creates a calibration from a measured duration and its nanosecond equivalent.
Sourcepub fn new_with_reference_clock<C: Clock<Time = WrappingU64Time>, R: Clock>(
clock: &C,
reference_clock: &CalibratedClock<R>,
min_duration: <R::Time as Time>::Duration,
wait: impl FnMut(<R::Time as Time>::Instant),
) -> (Self, ClockSynchronization<R::Time, C::Time>)
pub fn new_with_reference_clock<C: Clock<Time = WrappingU64Time>, R: Clock>( clock: &C, reference_clock: &CalibratedClock<R>, min_duration: <R::Time as Time>::Duration, wait: impl FnMut(<R::Time as Time>::Instant), ) -> (Self, ClockSynchronization<R::Time, C::Time>)
Calibrates clock against reference_clock, calling wait until min_duration elapses.
Returns the calibration and a ClockSynchronization relating the two clocks to each other
wait is invoked with the instant until which it should wait.
Sourcepub fn new_with_std_instant<C: Clock<Time = WrappingU64Time>>(
clock: &C,
min_duration: Duration,
) -> (Self, ClockSynchronization<InstantTime, C::Time>)
pub fn new_with_std_instant<C: Clock<Time = WrappingU64Time>>( clock: &C, min_duration: Duration, ) -> (Self, ClockSynchronization<InstantTime, C::Time>)
Calibrates clock against std::time::Instant, sleeping for at least min_duration.
This is a convenience wrapper around U64Calibration::new_with_reference_clock based on std::time::Instant and std::thread::sleep.